package cli::tsv::util;

use 5.006;
use strict;
use warnings;

=head1 NAME

cli::tsv::util - The great new cli::tsv::util!

=head1 VERSION

Version 0.512

=cut

our $VERSION = '0.512';


=head1 SYNOPSIS

The following 6 files (each with function explanation after ":" )
will be installed by folloinwg INSTALLATION instruction.

   1. colsummary : A great table decipher by looking into each coloumns.
   2. colgrep  : Extension of "grep" command searching on specified columns.
   3. colsplit  : Splitting a TSV file into files of the each column.
   4. colwidth   : Extracting `column width' informations.
   5. latextable  : Useful when you need latex tables from Excel/SQL results.
   6. csv2tsv 

  The function detail can be shown by --help after each command but 
  as of 2018.03.25, most of them is written in Japanese. Sorry. 

=head1 AUTHOR

"Toshiyuki Shimono", C<< <bin4tsv at gmail.com> >>


=head1 LICENSE AND COPYRIGHT

Copyright 2018 "Toshiyuki Shimono".

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see L<http://www.gnu.org/licenses/>.


=cut

1; # End of cli::tsv::util
